@@ -4,7 +4,7 @@ use warnings;
 use base qw/Exporter/;
 use 5.008001;
 
-our $VERSION = '3.08';
+our $VERSION = '3.09';
 
 use Carp ();
 use Furl::ConnectionCache;
@@ -208,7 +208,10 @@ sub make_x_www_form_urlencoded {
 
 sub env_proxy {
     my $self = shift;
-    $self->{proxy} = $ENV{HTTP_PROXY} || '';
+    # Under CGI, bypass HTTP_PROXY as request sets it from Proxy header
+    # Note: This doesn't work on windows correctly.
+    local $ENV{HTTP_PROXY} if $ENV{REQUEST_METHOD};
+    $self->{proxy} = $ENV{http_proxy} || $ENV{HTTP_PROXY} || $self->{proxy};
     $self->{no_proxy} = $ENV{NO_PROXY} || '';
     $self;
 }
@@ -483,6 +486,13 @@ sub request {
             else {
                 # succeeded
                 $rest_header = substr( $buf, $ret );
+                if ((int $res_status / 100) eq 1) { # Continue
+                    # The origin server must not wait for the request body
+                    # before sending the 100 (Continue) response.
+                    # see http://greenbytes.de/tech/webdav/rfc2616.html#status.100
+                    $buf = $rest_header;
+                    next LOOP;
+                }
                 last LOOP;
             }
         }
@@ -1083,7 +1093,7 @@ I<%args> might be:
 
 =item timeout :Int = 10
 
-Seconds until the call to $furl->request returns a timeout error (as an internally generated 500 error). The timeout might not be accurate since some underlying modules / built-ins function may block longer than the specified timeout. See the FAQ for how to support timeout during name resolution.
+Seconds until the call to $furl->request returns a timeout error (as an internally generated 500 error). The timeout might not be accurate since some underlying modules / built-ins function may block longer than the specified timeout. See the L</"FAQ"> for how to support timeout during name resolution.
 
 =item inactivity_timeout :Int = 600
 
@@ -1317,7 +1327,7 @@ which might confuse C<Keep-Alive> processes, so Furl closes connection in
 such cases.
 
 Anyway, the HEAD method is not so useful nowadays. The GET method and
-C<If-Modified-Sinse> are more suitable to cache HTTP contents.
+C<If-Modified-Since> are more suitable to cache HTTP contents.
 
 =item Why does Furl take longer than specified until it returns a timeout error?
 
@@ -1376,8 +1386,8 @@ This feature requires Compress::Raw::Zlib.
 
 To setup your environment:
 
-    $ git clone http://github.com/tokuhirom/p5-Furl.git
-    $ cd p5-Furl
+    $ git clone http://github.com/tokuhirom/Furl.git
+    $ cd Furl
 
 To get picohttpparser:
 
@@ -1390,7 +1400,7 @@ To get picohttpparser:
 
 =head2 HOW TO CONTRIBUTE
 
-Please send the pull request via L<http://github.com/tokuhirom/p5-Furl/>.
+Please send the pull request via L<http://github.com/tokuhirom/Furl/>.
 
 =head1 SEE ALSO
 
